<?php
/**
* Slider Section options
*
* @package Theme Palace
* @subpackage Teach Kiddo
* @since Teach Kiddo 1.0.0
*/

// Add Slider section
$wp_customize->add_section( 'teach_kiddo_slider_section', array(
	'title'             => esc_html__( 'Main Slider','teach-kiddo' ),
	'description'       => esc_html__( 'Slider Section options.', 'teach-kiddo' ),
	'panel'             => 'teach_kiddo_front_page_panel',
	) );

// Slider content enable control and setting
$wp_customize->add_setting( 'teach_kiddo_theme_options[slider_section_enable]', array(
	'default'			=> 	$options['slider_section_enable'],
	'sanitize_callback' => 'teach_kiddo_sanitize_switch_control',
	) );

$wp_customize->add_control( new Teach_Kiddo_Switch_Control( $wp_customize, 'teach_kiddo_theme_options[slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'teach-kiddo' ),
	'section'           => 'teach_kiddo_slider_section',
	'on_off_label' 		=> teach_kiddo_switch_options(),
	) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'teach_kiddo_theme_options[slider_section_enable]', array(
		'selector'            => '#featured-slider-section .tooltiptext',
		'settings'            => 'teach_kiddo_theme_options[slider_section_enable]',
    ) );
}

$wp_customize->add_setting( 'teach_kiddo_theme_options[slider_search_enable]', array(
	'default'			=> 	$options['slider_search_enable'],
	'sanitize_callback' => 'teach_kiddo_sanitize_switch_control',
	) );

$wp_customize->add_control( new Teach_Kiddo_Switch_Control( $wp_customize, 'teach_kiddo_theme_options[slider_search_enable]', array(
	'label'             => esc_html__( 'Slider Search Form Enable', 'teach-kiddo' ),
	'section'           => 'teach_kiddo_slider_section',
	'on_off_label' 		=> teach_kiddo_switch_options(),
	) ) );

// long Excerpt length setting and control.
$wp_customize->add_setting( 'teach_kiddo_theme_options[slider_excerpt_length]', array(
	'sanitize_callback' => 'teach_kiddo_sanitize_number_range',
	'validate_callback' => 'teach_kiddo_validate_long_excerpt',
	'default'			=> $options['slider_excerpt_length'],
	) );

$wp_customize->add_control( 'teach_kiddo_theme_options[slider_excerpt_length]', array(
	'label'       		=> esc_html__( 'Slider Excerpt Length', 'teach-kiddo' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in slider posts.', 'teach-kiddo' ),
	'section'     		=> 'teach_kiddo_slider_section',
	'active_callback' 	=> 'teach_kiddo_is_slider_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
		),
	) );


for ( $i = 1; $i <= 3; $i++ ) :

// slider pages drop down chooser control and setting
$wp_customize->add_setting( 'teach_kiddo_theme_options[slider_content_page_' . $i . ']', array(
	'sanitize_callback' => 'teach_kiddo_sanitize_page',
	) );

$wp_customize->add_control( new Teach_Kiddo_Dropdown_Chooser( $wp_customize, 'teach_kiddo_theme_options[slider_content_page_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Page %d', 'teach-kiddo' ), $i ),
	'section'           => 'teach_kiddo_slider_section',
	'choices'			=> teach_kiddo_page_choices(),
	'active_callback'	=> 'teach_kiddo_is_slider_section_enable',
	) ) );
endfor;
